@@ -1,3 +1,14 @@
+MakeUrl <- function(parsedUrl) {
+  paste0(parsedUrl$scheme, "://", parsedUrl$hostname, "/")
+}
+
+DataRobotBrowse <- function(urlString, model) {
+  routeString <- paste0(urlString,
+                        "projects/", model$projectId, "/models/",  # nolint
+                        model$modelId)
+  browseURL(routeString)
+}
+
 #' Retrieve a DataRobot web page that displays detailed model information
 #'
 #' This function brings up a web page that displays detailed model
@@ -14,41 +25,12 @@
 #' }
 #' @export
 ViewWebModel <- function(model) {
-  #
-  ########################################################################
-  #
-  #  Function to retrieve a web-page that contains information about model
-  #
-  ########################################################################
-  #
-  #  Validate model
-  #
   validModel <- ValidateModel(model)
-  #
-  #  GET Datarobot endpoint URL
-  #
   dataRobotUrl <- Sys.getenv("DATAROBOT_API_ENDPOINT")
-  #
   parsedUrl <- httr::parse_url(dataRobotUrl)
-  #
-  #  Specify route for web-browser
-  #
-  #    This statement gives an absolute_paths_linter false positive:
-  #
-  routeString <- paste0(parsedUrl['scheme'], '://',
-                       parsedUrl['hostname'], '/',
-                       "projects/", model$projectId, "/models/",  # nolint
-                       model$modelId)
-  #
-  #  Invoke browser to open specified route
-  #
-  browseURL(routeString)
-  #
-  #  Display user message and return logical value
-  #
+  urlString <- MakeUrl(parsedUrl)
+  DataRobotBrowse(urlString, model)
   modelType <- validModel$modelType
-  urlString <- paste0(parsedUrl['scheme'], '://',
-                     parsedUrl['hostname'], '/')
   if (is.null(modelType)) {
     message(paste("Opened URL", urlString, "for selected model"))
   } else {
